pub struct NativeAdditionalData {
pub program: Option<String>,
}Expand description
Additional data for native runtime. This is used to pass additional data from the compiler to the runtime.
Fields
program: Option<String>Program that should be used to run the code.
Default is None, which means that the executable will be treated as a program.